@@ -1,12 +1,15 @@
 #!/usr/bin/env python
 
-# ----------------------------------------------------------------------------
-# Copyright (c) 2013--, scikit-bio development team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file LICENSE.txt, distributed with this software.
-# ----------------------------------------------------------------------------
+"""Validate the content and structure of a scikit-bio repository.
+
+----------------------------------------------------------------------------
+Copyright (c) 2013--, scikit-bio development team.
+
+Distributed under the terms of the Modified BSD License.
+
+The full license is in the file LICENSE.txt, distributed with this software.
+----------------------------------------------------------------------------
+"""
 
 import collections
 import os
@@ -20,12 +23,15 @@ import warnings
 import dateutil.parser
 
 if sys.version_info.major != 3:
-    sys.exit("scikit-bio can only be used with Python 3. You are currently "
-             "running Python %d." % sys.version_info.major)
+    sys.exit(
+        "scikit-bio can only be used with Python 3. You are currently "
+        "running Python %d." % sys.version_info.major
+    )
 
 
 class ChecklistWarning(Warning):
     """General warning class for warnings raised by checklist.py."""
+
     pass
 
 
@@ -44,10 +50,14 @@ def main():
         as an exit code (e.g. for use with ``sys.exit``).
 
     """
-    root = 'skbio'
-    validators = [InitValidator(), CopyrightHeadersValidator(),
-                  ExecPermissionValidator(), GeneratedCythonValidator(),
-                  APIRegressionValidator()]
+    root = "skbio"
+    validators = [
+        InitValidator(),
+        CopyrightHeadersValidator(),
+        ExecPermissionValidator(),
+        GeneratedCythonValidator(),
+        APIRegressionValidator(),
+    ]
 
     return_code = 0
     for validator in validators:
@@ -55,8 +65,8 @@ def main():
 
         if not success:
             return_code = 1
-            sys.stderr.write('\n'.join(msg))
-            sys.stderr.write('\n\n')
+            sys.stderr.write("\n".join(msg))
+            sys.stderr.write("\n\n")
 
     return return_code
 
@@ -73,7 +83,8 @@ class RepoValidator:
     created by ``validate``.
 
     """
-    reason = ''
+
+    reason = ""
 
     def validate(self, root):
         """Validate a directory tree recursively.
@@ -144,8 +155,13 @@ class RepoValidator:
         https://github.com/biocore/verman for more details.
 
         """
-        proc = subprocess.Popen(cmd, shell=True, universal_newlines=True,
-                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        proc = subprocess.Popen(
+            cmd,
+            shell=True,
+            universal_newlines=True,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
 
         # communicate pulls all stdout/stderr from the PIPEs to
         # avoid blocking -- don't remove this line!
@@ -155,10 +171,10 @@ class RepoValidator:
 
 
 class CopyrightHeadersValidator(RepoValidator):
-    """Flag library files with non-standard copyright headers
+    """Flag library files with non-standard copyright headers.
 
     See the current standard for scikit-bio's copyright headers at
-    ``http://scikit-bio.org/docs/latest/development/new_module.html``
+    ``https://scikit.bio/devdoc/new_module.html``
 
     Individual files are ignored if the first line in the file is exactly:
 
@@ -175,8 +191,10 @@ class CopyrightHeadersValidator(RepoValidator):
 
     """
 
-    reason = ("Files non-conforming to standard headers as described in\n"
-              "http://scikit-bio.org/docs/latest/development/new_module.html:")
+    reason = (
+        "Files non-conforming to standard headers as described in\n"
+        "https://scikit.bio/devdoc/new_module.html:"
+    )
 
     COPYRIGHT_HEADER = """\
 # ----------------------------------------------------------------------------
@@ -189,8 +207,9 @@ class CopyrightHeadersValidator(RepoValidator):
 """
 
     def __init__(self, skip_dirs=None):
+        """Initialize with directories to skip."""
         if skip_dirs is None:
-            skip_dirs = {'data', '__pycache__'}
+            skip_dirs = {"data", "__pycache__"}
         self.skip_dirs = set(skip_dirs)
 
     def _validate(self, root, dirs, files):
@@ -200,19 +219,20 @@ class CopyrightHeadersValidator(RepoValidator):
 
         invalid_files = []
         for _file in files:
-            if not _file.endswith('.py'):
+            if not _file.endswith(".py"):
                 continue
 
             pos = 0
             filepath = os.path.join(root, _file)
             f = open(filepath)
 
-            first_line = f.readline().rstrip('\n')
-            if first_line == '# checklist.py:CopyrightHeadersValidator IGNORE':
+            first_line = f.readline().rstrip("\n")
+            if first_line == "# checklist.py:CopyrightHeadersValidator IGNORE":
                 warnings.warn(
                     "File %s has IGNORE directive. Ignoring scikit-bio "
                     "copyright header validation." % filepath,
-                    ChecklistWarning)
+                    ChecklistWarning,
+                )
                 continue
 
             f.seek(0)
@@ -226,11 +246,12 @@ class CopyrightHeadersValidator(RepoValidator):
                 pos += 3
             # copyright header consists of 7 lines, and by discussion in
             # preceding comment, spans through 14 tokens.
-            cheader = ''.join(map(lambda x: x[1], tokens[pos:pos + 14]))
+            cheader = "".join(map(lambda x: x[1], tokens[pos : pos + 14]))
             # Ensure that there is no blank line at the end of the file
-            if (cheader != self.COPYRIGHT_HEADER or
-                    (tokens[pos + 14][0] != tokenize.NL and
-                     tokens[pos + 14][0] != tokenize.ENDMARKER)):
+            if cheader != self.COPYRIGHT_HEADER or (
+                tokens[pos + 14][0] != tokenize.NL
+                and tokens[pos + 14][0] != tokenize.ENDMARKER
+            ):
                 invalid_files.append(f.name)
             f.close()
 
@@ -254,11 +275,13 @@ class InitValidator(RepoValidator):
         contained within them).
 
     """
+
     reason = "Directories missing init files:"
 
     def __init__(self, skip_dirs=None):
+        """Initialize with directories to skip."""
         if skip_dirs is None:
-            skip_dirs = {'data', '__pycache__'}
+            skip_dirs = {"data", "__pycache__"}
         self.skip_dirs = set(skip_dirs)
 
     def _validate(self, root, dirs, files):
@@ -271,7 +294,7 @@ class InitValidator(RepoValidator):
                 dirs.remove(skip_dir)
 
         invalid_dirs = []
-        if '__init__.py' not in files:
+        if "__init__.py" not in files:
             invalid_dirs.append(root)
         return invalid_dirs
 
@@ -286,11 +309,13 @@ class ExecPermissionValidator(RepoValidator):
         C files (header and source files).
 
     """
+
     reason = "Library code with execute permissions:"
 
     def __init__(self, extensions=None):
+        """Initialize with specific file extensions."""
         if extensions is None:
-            extensions = {'.py', '.pyx', '.h', '.c'}
+            extensions = {".py", ".pyx", ".h", ".c"}
         self.extensions = set(extensions)
 
     def _validate(self, root, dirs, files):
@@ -323,9 +348,11 @@ class GeneratedCythonValidator(RepoValidator):
         File extension for generated C files.
 
     """
+
     reason = "Cython code with missing or outdated generated C code:"
 
-    def __init__(self, cython_ext='.pyx', c_ext='.c'):
+    def __init__(self, cython_ext=".pyx", c_ext=".c"):
+        """Initialize with specific file extensions."""
         self.cython_ext = cython_ext
         self.c_ext = c_ext
 
@@ -364,8 +391,9 @@ class GeneratedCythonValidator(RepoValidator):
         stdout, stderr, retval = self._system_call(cmd)
 
         if retval != 0:
-            raise RuntimeError("Could not execute 'git log' command to "
-                               "determine file timestamp.")
+            raise RuntimeError(
+                "Could not execute 'git log' command to " "determine file timestamp."
+            )
         return dateutil.parser.parse(stdout.strip())
 
 
@@ -379,10 +407,11 @@ class APIRegressionValidator(RepoValidator):
     least deep API target.
 
     """
-    reason = ("The following tests import `A` but should import `B`"
-              " (file: A => B):")
+
+    reason = "The following tests import `A` but should import `B`" " (file: A => B):"
 
     def __init__(self):
+        """Initialize object for tests importing from non-minimized hierarchy."""
         self._imports = {}
 
     def _validate(self, root, dirs, files):
@@ -406,8 +435,7 @@ class APIRegressionValidator(RepoValidator):
             for import_ in imports:
                 substitute = self._minimal_import(import_)
                 if substitute is not None:
-                    errors.append("%s: %s => %s" %
-                                  (fp, import_, substitute))
+                    errors.append("%s: %s => %s" % (fp, import_, substitute))
 
         return errors
 
@@ -418,12 +446,12 @@ class APIRegressionValidator(RepoValidator):
             # The actual object imported will be the key.
             key = import_.split(".")[-1]
             # If package importing the behavior is shorter than its import:
-            if len(package.split('.')) + 1 < len(import_.split('.')):
+            if len(package.split(".")) + 1 < len(import_.split(".")):
                 value = ".".join([package, key])
 
             if key in self._imports:
                 sub = self._imports[key]
-                if len(sub.split('.')) > len(value.split('.')):
+                if len(sub.split(".")) > len(value.split(".")):
                     self._imports[key] = value
             else:
                 self._imports[key] = value
@@ -434,7 +462,7 @@ class APIRegressionValidator(RepoValidator):
         if key not in self._imports:
             return None
         substitute = self._imports[key]
-        if len(substitute.split('.')) == len(import_.split('.')):
+        if len(substitute.split(".")) == len(import_.split(".")):
             return None
         else:
             return substitute
@@ -457,7 +485,7 @@ class APIRegressionValidator(RepoValidator):
                     if node.level > 0:
                         prefix = root
                         extra = node.level - 1
-                        while (extra > 0):
+                        while extra > 0:
                             # Keep dropping...
                             prefix = os.path.split(prefix)[0]
                             extra -= 1
@@ -466,8 +494,9 @@ class APIRegressionValidator(RepoValidator):
                     # Prefix should be empty unless node.level > 0
                     if node.module is None:
                         node.module = ""
-                    imports += [".".join([prefix + node.module, x.name])
-                                for x in node.names]
+                    imports += [
+                        ".".join([prefix + node.module, x.name]) for x in node.names
+                    ]
         skbio_imports = []
         for import_ in imports:
             # Filter by skbio
@@ -476,5 +505,5 @@ class APIRegressionValidator(RepoValidator):
         return skbio_imports
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main())
