@@ -11,12 +11,15 @@
 # Instructions:
 # https://www.sphinx-doc.org/en/master/usage/configuration.html
 
-import os
 import sys
+import inspect
 from datetime import datetime
+from os.path import abspath, relpath, dirname
 
 import skbio
 
+sys.path.insert(0, abspath('.'))
+
 
 # -- Project information -----------------------------------------------------
 
@@ -41,7 +44,8 @@ extensions = [
     'numpydoc',
     'sphinx_design',
     'sphinx_copybutton',
-    'matplotlib.sphinxext.plot_directive'
+    'matplotlib.sphinxext.plot_directive',
+    'sphinx_sitemap',
 ]
 
 root_doc = 'index'
@@ -84,18 +88,29 @@ html_css_files = ['css/style.css']
 # do not show source links
 html_show_sourcelink = False
 
+# do not show () after function link
+add_function_parentheses = False
+
 
 # -- External links ----------------------------------------------------------
 
 github_url = f'https://github.com/{project}/{project}'
 twitter_url = 'https://twitter.com/scikitbio'
+wiki_url = 'https://en.wikipedia.org/wiki'
 
 extlinks = {
     'home': (f'{html_baseurl}/%s', None),
     'repo': (f'{github_url}/%s', None),
+    'wiki': (f'{wiki_url}/%s', None),
 }
 
 
+# -- Sitemap configuration ---------------------------------------------------
+
+doc_dir = 'dev' if version.endswith('-dev') else version
+sitemap_url_scheme = f'/docs/{doc_dir}/{{link}}'
+
+
 # -- numpydoc configuration --------------------------------------------------
 
 # References:
@@ -125,12 +140,6 @@ html_theme_options = {
       'image_dark': '_static/logo_inv.svg',
     },
 
-    # announcement banner on top of the screen
-    # 'announcement': (
-    #     f"{project} is back in active development! Check out our <a href='"
-    #     f"{github_url}/discussions/1935'>announcement of revitalization</a>."
-    # ),
-
     # social media links displayed as icons
     'github_url': github_url,
     'twitter_url': twitter_url,
@@ -141,7 +150,7 @@ html_theme_options = {
     # version switcher
     'switcher': {
         'json_url': f'{html_baseurl}/versions.json',
-        'version_match': 'dev' if version.endswith('-dev') else version,
+        'version_match': doc_dir,
     },
 
     # simplify section navigation
@@ -178,6 +187,8 @@ intersphinx_mapping = {
     'scipy': ('https://docs.scipy.org/doc/scipy/', None),
     'matplotlib': ('https://matplotlib.org/stable/', None),
     'pandas': ('https://pandas.pydata.org/pandas-docs/stable/', None),
+    'sklearn': ('https://scikit-learn.org/stable/', None),
+    'statsmodels': ('https://www.statsmodels.org/stable/', None),
     'biom-format': ('https://biom-format.org/', None)
 }
 
@@ -195,10 +206,6 @@ plot_html_show_formats = False
 
 # -- Source code links --------------------------------------------------------
 
-import inspect
-from os.path import relpath, dirname
-
-
 def linkcode_resolve(domain, info):
     """Determine the URL corresponding to a Python object.
     """
@@ -258,3 +265,19 @@ def _closure():
 
     classproperty.__get__ = __get__
 _closure()
+
+
+# Import the patched autosummary extension to support automatic inheritance.
+
+from autoinherit import InheritedAutosummary
+
+
+# Let autosummary skip members that have a "skipdoc" attribute that is True.
+
+def skip_member(app, what, name, obj, skip, options):
+    return getattr(obj, "_skipdoc", None)
+
+
+def setup(app):
+    app.add_directive('autoinherit', InheritedAutosummary)
+    app.connect("autodoc-skip-member", skip_member)
