@@ -17,6 +17,7 @@ class SkbioObject(metaclass=abc.ABCMeta):
     be implemented in subclasses, otherwise they will not be instantiable.
 
     """
+
     @abc.abstractmethod
     def __str__(self):
         raise NotImplementedError
@@ -50,7 +51,7 @@ class ElasticLines:
         self._separator_idxs.append(len(self._lines) - 1)
 
     def to_str(self):
-        separator = '-' * self._max_line_len
+        separator = "-" * self._max_line_len
         for idx in self._separator_idxs:
             self._lines[idx] = separator
-        return '\n'.join(self._lines)
+        return "\n".join(self._lines)
