@@ -35,7 +35,8 @@
  *
  */
 
-#include <emmintrin.h>
+#define SIMDE_ENABLE_NATIVE_ALIASES
+#include "simde-sse2.h"
 #include <stdint.h>
 #include <stdlib.h>
 #include <stdio.h>
