@@ -23,7 +23,7 @@ def _validate_counts_vector(counts, cast_int=False):
     counts : array_like of int or float of shape (n_taxa,)
         Vector of counts.
     cast_int : bool, optional
-        Cast values into integers, if not already. ``False`` by default.
+        Whether cast values into integers, if not already. Default is False.
 
     Returns
     -------
@@ -86,7 +86,7 @@ def _validate_counts_matrix(counts, ids=None, cast_int=False):
     ids : array_like of shape (n_samples,), optional
         Sample IDs to check against counts dimensions.
     cast_int : bool, optional
-        Cast values into integers, if not already. ``False`` by default.
+        Whether cast values into integers, if not already. Default is False.
 
     Returns
     -------
@@ -183,7 +183,7 @@ def _validate_taxa_and_tree(counts, taxa, tree, rooted=True):
         )
 
 
-def _vectorize_counts_and_tree(counts, taxa, tree):
+def vectorize_counts_and_tree(counts, taxa, tree):
     """Index tree and convert counts to np.array in corresponding order.
 
     Parameters
@@ -209,6 +209,18 @@ def _vectorize_counts_and_tree(counts, taxa, tree):
     --------
     skbio.tree.TreeNode.to_array
 
+    Notes
+    -----
+    Leveraging internal node counts in the tree (in addition to tip abundances) can
+    double the accuracy in downstream machine learning pipelines [1]_.
+
+    References
+    ----------
+    .. [1] Martino C., McDonald D., Cantrell K., Dilmore AH., Vázquez-Baeza Y.,
+       Shenhav L., Shaffer J.P., Rahman G., Armstrong G., Allaband C., Song S.J.,
+       Knight R. Compositionally aware phylogenetic beta-diversity measures better
+       resolve microbiomes associated with phenotype. mSystems. 7(3) (2022).
+
     """
     tree_index = tree.to_array(nan_length_value=0.0)
     taxa = np.asarray(taxa)
@@ -239,7 +251,7 @@ def _quantitative_to_qualitative_counts(counts):
 
 
 def _check_taxa_alias(taxa, tree, otu_ids):
-    # make `taxa` an alias of `taxa`; for backward compatibility
+    # make `otu_ids` an alias of `taxa`; for backward compatibility
     if taxa is None:
         if otu_ids is None:
             raise ValueError("A list of taxon IDs must be provided.")
@@ -272,10 +284,10 @@ def _validate_table(counts, ids, kwargs):
     WARNING: this implicitly adds an entry to kwargs IF `tree` is present.
     """
     if ids is not None:
-        raise ValueError("Cannot provide a `Table` as `counts` and `ids`")
+        raise ValueError("Cannot provide a `Table` as `counts` and `ids`.")
 
     if "taxa" in kwargs:
-        raise ValueError("Cannot provide a `Table` as `counts` and `taxa`")
+        raise ValueError("Cannot provide a `Table` as `counts` and `taxa`.")
 
     dense_counts, sample_ids, feature_ids = _table_to_numpy(counts)
     if "tree" in kwargs:
