@@ -15,7 +15,7 @@ from scipy.optimize import fmin_powell, minimize_scalar
 
 from skbio.stats import subsample_counts
 from skbio.diversity._util import _validate_counts_vector
-from skbio.util._warning import _warn_deprecated
+from skbio.util._decorator import aliased
 
 
 def _validate_alpha(empty=None, cast_int=False):
@@ -29,7 +29,7 @@ def _validate_alpha(empty=None, cast_int=False):
         Return this value if set instead of calling the function when an input
         community is empty (i.e., no taxon, or all taxa have zero counts).
     cast_int : bool, optional
-        Cast values into integers, if not already. ``False`` by default.
+        Whether cast values into integers, if not already. Default is False.
 
     Returns
     -------
@@ -188,7 +188,7 @@ def dominance(counts, finite=False):
     counts : 1-D array_like, int
         Vector of counts.
     finite : bool, optional
-        If ``True``, correct for finite sampling.
+        If True, correct for finite sampling.
 
     Returns
     -------
@@ -255,7 +255,7 @@ def enspie(counts, finite=False):
     counts : 1-D array_like, int
         Vector of counts.
     finite : bool, optional
-        If ``True``, correct for finite sampling.
+        If True, correct for finite sampling.
 
     Returns
     -------
@@ -657,7 +657,7 @@ def inv_simpson(counts, finite=False):
     counts : 1-D array_like, int
         Vector of counts.
     finite : bool, optional
-        If ``True``, correct for finite sampling when calculating :math:`D`.
+        If True, correct for finite sampling when calculating :math:`D`.
 
     Returns
     -------
@@ -971,39 +971,6 @@ def observed_features(counts):
     return sobs(counts)
 
 
-def observed_otus(counts):
-    """Calculate the number of distinct OTUs.
-
-    Parameters
-    ----------
-    counts : 1-D array_like, int
-        Vector of counts.
-
-    Returns
-    -------
-    int
-        Distinct OTU count.
-
-    Warnings
-    --------
-    ``observed_otus`` is deprecated as of ``0.6.0`` due to its usage of the
-    historical term "OTU".
-
-    See Also
-    --------
-    sobs
-
-    Notes
-    -----
-    ``observed_otus`` is an alias for ``sobs``.
-
-    """
-    # @deprecated
-    _warn_deprecated(observed_otus, "0.6.0")
-
-    return sobs(counts)
-
-
 @_validate_alpha()
 def osd(counts):
     """Calculate observed taxa, singletons, and doubletons.
@@ -1267,7 +1234,7 @@ def shannon(counts, base=None, exp=False):
             consistency with the majority of literature.
 
     exp : bool, optional
-        If ``True``, return the exponential of Shannon index.
+        If True, return the exponential of Shannon index.
 
     Returns
     -------
@@ -1327,7 +1294,7 @@ def simpson(counts, finite=False):
     counts : 1-D array_like, int
         Vector of counts.
     finite : bool, optional
-        If ``True``, correct for finite sampling when calculating :math:`D`.
+        If True, correct for finite sampling when calculating :math:`D`.
 
     Returns
     -------
@@ -1364,7 +1331,7 @@ def simpson_d(counts, finite=False):
     counts : 1-D array_like, int
         Vector of counts.
     finite : bool, optional
-        If ``True``, correct for finite sampling.
+        If True, correct for finite sampling.
 
     Returns
     -------
@@ -1457,6 +1424,7 @@ def singles(counts):
     return (counts == 1).sum()
 
 
+@aliased("observed_otus", "0.6.0", True)
 @_validate_alpha()
 def sobs(counts):
     """Calculate the observed species richness of a sample.
