@@ -1,5 +1,4 @@
-"""
-Beta diversity measures (:mod:`skbio.diversity.beta`)
+"""Beta diversity measures (:mod:`skbio.diversity.beta`)
 =====================================================
 
 .. currentmodule:: skbio.diversity.beta
@@ -18,7 +17,7 @@ Functions
     unweighted_unifrac
     weighted_unifrac
 
-"""
+"""  # noqa: D205, D415
 
 # ----------------------------------------------------------------------------
 # Copyright (c) 2013--, scikit-bio development team.
