@@ -18,7 +18,7 @@ from skbio.table import example_table
 from skbio.diversity._util import (_validate_counts_vector,
                                    _validate_counts_matrix,
                                    _validate_taxa_and_tree,
-                                   _vectorize_counts_and_tree,
+                                   vectorize_counts_and_tree,
                                    _quantitative_to_qualitative_counts,
                                    _check_taxa_alias,
                                    _table_to_numpy,
@@ -270,7 +270,7 @@ class ValidationTests(TestCase):
         tree = TreeNode.read(io.StringIO("((a:1, b:2)c:3)root;"))
         counts = np.array([[0, 1], [1, 5], [10, 1]])
         count_array, indexed, branch_lengths = \
-            _vectorize_counts_and_tree(counts, np.array(['a', 'b']), tree)
+            vectorize_counts_and_tree(counts, np.array(['a', 'b']), tree)
         exp_counts = np.array([[0, 1, 10], [1, 5, 1], [1, 6, 11], [1, 6, 11]])
         npt.assert_equal(count_array, exp_counts.T)
 
