@@ -5,6 +5,24 @@ r"""Input and Output (:mod:`skbio.io`)
 
 This module provides input/output (I/O) functionality for scikit-bio.
 
+In bioinformatics there are many different file formats, and in scikit-bio there are
+many different classes which can read and write these formats. The many-to-many
+nature of the relationships between scikit-bio objects and file formats inspired
+the creation of the scikit-bio ``io`` module, which manages these relationships
+transparently.
+
+For general guidance on reading and writing files and working with scikit-bio objects,
+see the :ref:`tutorial` section and the
+`Reading and writing files <https://github.com/scikit-bio/scikit-bio-cookbook/blob/
+master/Reading%20and%20writing%20files.ipynb>`_
+notebook. For guidance on a specific format or scikit-bio object,
+see the documentation for that format or object.
+
+See the
+`IORegistry docs <https://scikit.bio/docs/latest/generated/skbio.io.registry.html
+#creating-a-new-format-for-scikit-bio>`_
+for guidance on creating custom formats and registering custom readers, writers, and
+sniffers.
 
 Supported file formats
 ----------------------
@@ -74,7 +92,7 @@ Develop custom formats
 
 
 Exceptions and warnings
-^^^^^^^^^^^^^^^^^^^^^^^
+-----------------------
 
 .. currentmodule:: skbio.io
 
@@ -108,17 +126,19 @@ Exceptions and warnings
    StockholmFormatError
 
 
+.. _tutorial:
+
 Tutorial
 --------
 
 Reading and writing files (I/O) can be a complicated task:
 
 * A file format can sometimes be read into more than one in-memory representation
-  (i.e., object). For example, a FASTA file can be read into an
-  :class:`skbio.alignment.TabularMSA` or :class:`skbio.sequence.DNA` depending on
+  (i.e., object). For example, a FASTA file can be read into a
+  :class:`~skbio.alignment.TabularMSA` or :class:`~skbio.sequence.DNA` depending on
   what operations you'd like to perform on your data.
 * A single object might be writeable to more than one file format. For example, an
-  :class:`skbio.alignment.TabularMSA` object could be written to FASTA, FASTQ,
+  :class:`~skbio.alignment.TabularMSA` object could be written to FASTA, FASTQ,
   CLUSTAL, or PHYLIP formats, just to name a few.
 * You might not know the exact file format of your file, but you want to read
   it into an appropriate object.
@@ -129,7 +149,7 @@ Reading and writing files (I/O) can be a complicated task:
 
 To address these issues (and others), scikit-bio provides a simple, powerful
 interface for dealing with I/O. We accomplish this by using a single I/O
-registry.
+registry defined in :class:`~skbio.io.registry.IORegistry`.
 
 What kinds of files scikit-bio can use
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -145,24 +165,38 @@ procedural interface:
 
    my_obj = skbio.io.read(file, format='someformat', into=SomeSkbioClass)
 
-The second is to use the object-oriented (OO) interface which is automatically
-constructed from the procedural interface:
+Here, ``file`` can be a path to a file, a file handle, or any of the other
+objects with read support listed in the :func:`skbio.io.util.open` documentation.
+
+The second way to read files is to use the object-oriented interface, which is
+automatically constructed from the procedural interface:
 
 .. code-block:: python
 
    my_obj = SomeSkbioClass.read(file, format='someformat')
 
-For example, to read a ``newick`` file using both interfaces you would type:
+.. note::
+   A very common use case in bioinformatics is to read multi-line FASTA and
+   FASTQ files. For examples on how to achieve this with scikit-bio, please see the
+   `FASTA documentation <https://scikit.bio/docs/dev/generated/skbio.io.format.fasta.html
+   #examples>`_
+   or the
+   `FASTQ documentation <https://scikit.bio/docs/dev/generated/skbio.io.format.fastq.html
+   #examples>`_.
 
->>> from skbio import read
+As an example, let's read a :mod:`~skbio.io.format.newick` file into a
+:class:`~skbio.tree.TreeNode` object using both interfaces. Here we will use Python's
+built-in :class:`~io.StringIO` class to mimick an open file:
+
+>>> from skbio import read as sk_read
 >>> from skbio import TreeNode
 >>> from io import StringIO
 >>> open_filehandle = StringIO('(a, b);')
->>> tree = read(open_filehandle, format='newick', into=TreeNode)
+>>> tree = sk_read(open_filehandle, format='newick', into=TreeNode)
 >>> tree
 <TreeNode, name: unnamed, internal node count: 0, tips count: 2>
 
-For the OO interface:
+Or, using the object-oriented interface:
 
 >>> open_filehandle = StringIO('(a, b);')
 >>> tree = TreeNode.read(open_filehandle, format='newick')
@@ -174,9 +208,9 @@ generator will be returned. What the generator yields will depend on what
 format is being read.
 
 When ``into`` is provided, format may be omitted and the registry will use its
-knowledge of the available formats for the requested class to infer the correct
-format. This format inference is also available in the OO interface, meaning
-that ``format`` may be omitted there as well.
+knowledge of the available formats for the requested class to infer (sniff) the
+correct format. This format inference is also available in the object-oriented
+interface, meaning that ``format`` may be omitted there as well.
 
 As an example:
 
@@ -190,8 +224,11 @@ class of Python's standard library. The goal of a ``sniffer`` is two-fold: to
 identify if a file is a specific format, and if it is, to provide ``**kwargs``
 which can be used to better parse the file.
 
-.. note:: There is a built-in ``sniffer`` which results in a useful error message
-   if an empty file is provided as input and the format was omitted.
+.. note::
+   There is a built-in ``sniffer`` which results in a useful error message
+   if an empty file is provided as input and the format was omitted. See the
+   `sniff documentation <https://scikit.bio/docs/dev/generated/skbio.io.registry.sniff.
+   html>`_ for more information.
 
 Writing files from scikit-bio
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -203,15 +240,34 @@ Procedural Interface:
 
    skbio.io.write(my_obj, format='someformat', into=file)
 
-OO Interface:
+Object-oriented Interface:
 
 .. code-block:: python
 
    my_obj.write(file, format='someformat')
 
 In the procedural interface, ``format`` is required. Without it, scikit-bio does
-not know how you want to serialize an object. OO interfaces define a default
-``format``, so it may not be necessary to include it.
+not know how you want to serialize an object. Object-oriented interfaces define a
+default ``format``, so it may not be necessary to include it.
+
+For more information on writing to a specific file format, please see that format's
+documentation page.
+
+Streaming files with read and write
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+If you are working with particularly large files, streaming them might be preferable.
+For instance, if your file is larger than your available memory, you won't be able
+to read the entire file into memory at once. One way to get around this is to use
+streaming. Scikit-bio's ``io`` module offers the ability to contruct a streaming
+interface from the ``read`` and ``write`` functions.
+
+``skbio.io.read`` returns a generator, which can then be passed to ``skbio.io.write``
+to write only one chunk from the generator at a time.
+
+.. code-block:: python
+
+   seq_gen = skbio.io.read(big_file, format='someformat')
+   skbio.io.write(seq_gen, into=write_file, format='someformat')
 
 
 """  # noqa: D205, D415
@@ -308,7 +364,3 @@ import_module("skbio.io.format.embed")
 # This is meant to be a handy indicator to the user that they have done
 # something wrong.
 import_module("skbio.io.format.emptyfile")
-
-# Now that all of our I/O has loaded, we can add the object oriented methods
-# (read and write) to each class which has registered I/O operations.
-io_registry.monkey_patch()
