@@ -633,24 +633,26 @@ class TestSniff(RegistryTest):
         fmt, _ = self.registry.sniff(fp)
         self.assertEqual(fmt, 'formatx')
 
-    def test_position_not_mutated_real_file(self):
-        formatx = self.registry.create_format('formatx')
+    # Temporarily disabled due to a compatibility issue with conda-forge.
+    # See: https://github.com/scikit-bio/scikit-bio/issues/2088
+    # def test_position_not_mutated_real_file(self):
+    #     formatx = self.registry.create_format('formatx')
 
-        @formatx.sniffer()
-        def sniffer(fh):
-            return True, {}
+    #     @formatx.sniffer()
+    #     def sniffer(fh):
+    #         return True, {}
 
-        with io.open(get_data_path('real_file')) as fh:
-            if platform == "win32":
-                fh.seek(3)
-                self.registry.sniff(fh)
-                self.assertEqual(fh.tell(), 3)
-                self.assertEqual('b\n', fh.readline())
-            else:
-                fh.seek(2)
-                self.registry.sniff(fh)
-                self.assertEqual(fh.tell(), 2)
-                self.assertEqual('b\n', fh.readline())
+    #     with io.open(get_data_path('real_file')) as fh:
+    #         if platform == "win32":
+    #             fh.seek(3)
+    #             self.registry.sniff(fh)
+    #             self.assertEqual(fh.tell(), 3)
+    #             self.assertEqual('b\n', fh.readline())
+    #         else:
+    #             fh.seek(2)
+    #             self.registry.sniff(fh)
+    #             self.assertEqual(fh.tell(), 2)
+    #             self.assertEqual('b\n', fh.readline())
 
     def test_position_not_mutated_fileish(self):
         formatx = self.registry.create_format('formatx')
@@ -1722,207 +1724,6 @@ class TestWrite(RegistryTest):
         self.assertEqual(expected, f.getvalue())
 
 
-class TestMonkeyPatch(RegistryTest):
-    def setUp(self):
-        super(TestMonkeyPatch, self).setUp()
-
-        class UnassumingClass:
-            pass
-
-        class ClassWithDefault:
-            default_write_format = 'favfmt'
-
-        class NoMonkeySee:
-            pass
-
-        self.unassuming_class = UnassumingClass
-        self.class_with_default = ClassWithDefault
-        self.no_monkey_see = NoMonkeySee
-
-    def test_no_readers_writers(self):
-        self.registry.monkey_patch()
-        self.assertFalse(hasattr(self.unassuming_class, 'read'))
-        self.assertFalse(hasattr(self.unassuming_class, 'write'))
-        self.assertFalse(hasattr(self.class_with_default, 'read'))
-        self.assertFalse(hasattr(self.class_with_default, 'write'))
-
-    def test_readers_only(self):
-        favfmt = self.registry.create_format('favfmt')
-        favfmt2 = self.registry.create_format('favfmt2')
-
-        @favfmt.reader(self.unassuming_class)
-        def fvfmt_to_unasumming_class(fh):
-            return
-
-        @favfmt.reader(None)
-        def fvfmt_to_gen(fh):
-            yield
-
-        @favfmt2.reader(self.unassuming_class)
-        def fvfmt2_to_unasumming_class(fh):
-            return
-
-        self.registry.monkey_patch()
-
-        self.assertTrue(hasattr(self.unassuming_class, 'read'))
-        self.assertFalse(hasattr(self.unassuming_class, 'write'))
-        self.assertFalse(hasattr(self.class_with_default, 'read'))
-        self.assertFalse(hasattr(self.class_with_default, 'write'))
-
-        self.assertIn('favfmt', self.unassuming_class.read.__doc__)
-        self.assertIn('favfmt2', self.unassuming_class.read.__doc__)
-
-    def test_writers_only(self):
-        favfmt = self.registry.create_format('favfmt')
-        favfmt2 = self.registry.create_format('favfmt2')
-
-        @favfmt.writer(self.class_with_default)
-        def favfmt_writer(fh):
-            pass
-
-        @favfmt.writer(None)
-        def gen_to_favfmt(fh):
-            pass
-
-        @favfmt2.writer(self.class_with_default)
-        def favfmt2_writer(fh):
-            pass
-
-        self.registry.monkey_patch()
-
-        self.assertFalse(hasattr(self.unassuming_class, 'read'))
-        self.assertFalse(hasattr(self.unassuming_class, 'write'))
-        self.assertFalse(hasattr(self.class_with_default, 'read'))
-        self.assertTrue(hasattr(self.class_with_default, 'write'))
-
-        self.assertIn('favfmt', self.class_with_default.write.__doc__)
-        self.assertIn('favfmt2', self.class_with_default.write.__doc__)
-
-    def test_writers_no_default_format(self):
-        favfmt = self.registry.create_format('favfmt')
-        favfmt2 = self.registry.create_format('favfmt2')
-
-        @favfmt.writer(self.unassuming_class)
-        def favfmt_writer(fh):
-            pass
-
-        @favfmt.writer(None)
-        def gen_to_favfmt(fh):
-            pass
-
-        @favfmt2.writer(self.unassuming_class)
-        def favfmt2_writer(fh):
-            pass
-        with self.assertRaises(NotImplementedError) as cm:
-            self.registry.monkey_patch()
-
-        self.assertIn('default_write_format', str(cm.exception))
-
-    def test_readers_writers(self):
-        favfmt = self.registry.create_format('favfmt')
-        favfmt2 = self.registry.create_format('favfmt2')
-
-        @favfmt.reader(self.unassuming_class)
-        def fvfmt_to_unasumming_class(fh):
-            return
-
-        @favfmt.reader(self.class_with_default)
-        def fvfmt_to_class_w_default(fh):
-            return
-
-        @favfmt.reader(None)
-        def fvfmt_to_gen(fh):
-            yield
-
-        @favfmt2.reader(self.unassuming_class)
-        def fvfmt2_to_unasumming_class(fh):
-            return
-
-        @favfmt2.reader(self.class_with_default)
-        def fvfmt2_to_class_w_default(fh):
-            return
-
-        @favfmt.writer(self.class_with_default)
-        def favfmt_writer(fh):
-            pass
-
-        @favfmt.writer(None)
-        def gen_to_favfmt(fh):
-            pass
-
-        @favfmt2.writer(self.class_with_default)
-        def favfmt2_writer(fh):
-            pass
-
-        @favfmt2.reader(self.no_monkey_see, monkey_patch=True)
-        def favfmt2_to_monkey(fh):
-            pass
-
-        @favfmt2.writer(self.no_monkey_see, monkey_patch=False)
-        def monkey_to_favfmt2(fh):
-            pass
-
-        self.registry.monkey_patch()
-
-        self.assertTrue(hasattr(self.unassuming_class, 'read'))
-        self.assertFalse(hasattr(self.unassuming_class, 'write'))
-
-        self.assertTrue(hasattr(self.class_with_default, 'read'))
-        self.assertTrue(hasattr(self.class_with_default, 'write'))
-
-        self.assertTrue(hasattr(self.no_monkey_see, 'read'))
-        self.assertFalse(hasattr(self.no_monkey_see, 'write'))
-
-        self.assertIn('favfmt', self.unassuming_class.read.__doc__)
-        self.assertIn('favfmt2', self.unassuming_class.read.__doc__)
-
-        self.assertIn('favfmt', self.class_with_default.read.__doc__)
-        self.assertIn('favfmt2', self.class_with_default.read.__doc__)
-
-        self.assertIn('favfmt', self.class_with_default.write.__doc__)
-        self.assertIn('favfmt2', self.class_with_default.write.__doc__)
-
-        self.assertIn('favfmt2', self.no_monkey_see.read.__doc__)
-
-    def test_read_kwargs_passed(self):
-        favfmt = self.registry.create_format('favfmt')
-        self.was_called = False
-
-        @favfmt.sniffer()
-        def fvfmt_sniffer(fh):
-            return True, {}
-
-        @favfmt.reader(self.class_with_default)
-        def fvfmt_to_class_w_default(fh, **kwargs):
-            self.assertEqual('a', kwargs['a'])
-            self.assertEqual(123, kwargs['b'])
-            self.was_called = True
-
-        self.registry.monkey_patch()
-        fh = StringIO('notempty')
-        self.class_with_default.read(fh, a='a', b=123)
-
-        self.assertTrue(self.was_called)
-        fh.close()
-
-    def test_write_kwargs_passed(self):
-        favfmt = self.registry.create_format('favfmt')
-        self.was_called = False
-
-        @favfmt.writer(self.class_with_default)
-        def favfmt_writer(obj, fh, **kwargs):
-            self.assertEqual('a', kwargs['a'])
-            self.assertEqual(123, kwargs['b'])
-            self.was_called = True
-
-        self.registry.monkey_patch()
-        fh = StringIO()
-        self.class_with_default().write(fh, a='a', b=123)
-
-        self.assertTrue(self.was_called)
-        fh.close()
-
-
 class TestModuleFunctions(unittest.TestCase):
 
     def test_sniff_matches(self):
@@ -1954,6 +1755,10 @@ class TestModuleFunctions(unittest.TestCase):
         with self.assertRaises(DuplicateRegistrationError):
             create_format('fasta')
 
+    def test_remove_format_no_format(self):
+        with self.assertRaises(KeyError):
+            io_registry.remove_format('nonsense_asdf')
+
 
 if __name__ == '__main__':
     unittest.main()
