@@ -12,6 +12,7 @@ import functools
 
 from ._intersection import IntervalTree
 from skbio.util._decorator import classonlymethod
+from skbio.io.registry import Read, Write
 
 
 class Interval:
@@ -508,6 +509,9 @@ fuzzy=[(False, False)], metadata={'gene': 'sagB'})
 
     """
 
+    read = Read()
+    write = Write()
+
     default_write_format = "gff3"
 
     def __init__(self, upper_bound, copy_from=None):
