@@ -46,6 +46,15 @@ Distance calculation
    distance
 
 
+Abstract classes
+----------------
+
+.. autosummary::
+   :toctree: generated/
+
+   NucleotideMixin
+
+
 Tutorial
 --------
 
@@ -327,6 +336,7 @@ from ._rna import RNA
 from ._genetic_code import GeneticCode
 from ._grammared_sequence import GrammaredSequence
 from ._substitution import SubstitutionMatrix
+from ._nucleotide_mixin import NucleotideMixin
 
 __all__ = [
     "Sequence",
@@ -336,4 +346,5 @@ __all__ = [
     "GeneticCode",
     "GrammaredSequence",
     "SubstitutionMatrix",
+    "NucleotideMixin",
 ]
