@@ -10,7 +10,7 @@ from abc import ABCMeta, abstractproperty
 
 import numpy as np
 
-from skbio.util._decorator import classproperty, stable
+from skbio.util._decorator import classproperty
 from ._grammared_sequence import _motifs as parent_motifs
 
 
@@ -25,6 +25,7 @@ class NucleotideMixin(metaclass=ABCMeta):
     RNA
 
     """
+
     __complement_lookup = None
     __gc_codes = None
 
@@ -33,7 +34,7 @@ class NucleotideMixin(metaclass=ABCMeta):
         if cls.__complement_lookup is not None:
             return cls.__complement_lookup
 
-        lookup = np.zeros(cls._number_of_extended_ascii_codes, dtype=np.uint8)
+        lookup = np.zeros(cls._num_extended_ascii_codes, dtype=np.uint8)
         for key, value in cls.complement_map.items():
             lookup[ord(key)] = ord(value)
         cls.__complement_lookup = lookup
@@ -42,7 +43,7 @@ class NucleotideMixin(metaclass=ABCMeta):
     @classproperty
     def _gc_codes(cls):
         if cls.__gc_codes is None:
-            gc_iupac_chars = 'GCS'
+            gc_iupac_chars = "GCS"
             cls.__gc_codes = np.asarray([ord(g) for g in gc_iupac_chars])
         return cls.__gc_codes
 
@@ -52,7 +53,6 @@ class NucleotideMixin(metaclass=ABCMeta):
 
     @abstractproperty
     @classproperty
-    @stable(as_of='0.4.0')
     def complement_map(cls):
         """Return mapping of nucleotide characters to their complements.
 
@@ -69,7 +69,6 @@ class NucleotideMixin(metaclass=ABCMeta):
         """
         raise NotImplementedError
 
-    @stable(as_of='0.4.0')
     def complement(self, reverse=False):
         """Return the complement of the nucleotide sequence.
 
@@ -136,8 +135,8 @@ class NucleotideMixin(metaclass=ABCMeta):
             GC-content: 16.67%
         -----------------------------
         0 AATGAA
-        >>> rc.positional_metadata['quality'].values
-        array([5, 4, 3, 2, 1, 0])
+        >>> rc.positional_metadata['quality'].values # doctest: +ELLIPSIS
+        array([5, 4, 3, 2, 1, 0]...
 
         """
         result = self._complement_lookup[self._bytes]
@@ -151,9 +150,8 @@ class NucleotideMixin(metaclass=ABCMeta):
             positional_metadata = self.positional_metadata
 
         complement = self._constructor(
-            sequence=result,
-            metadata=metadata,
-            positional_metadata=positional_metadata)
+            sequence=result, metadata=metadata, positional_metadata=positional_metadata
+        )
 
         if reverse:
             # this has to be before the interval metadata code,
@@ -170,7 +168,6 @@ class NucleotideMixin(metaclass=ABCMeta):
 
         return complement
 
-    @stable(as_of='0.4.0')
     def reverse_complement(self):
         """Return the reverse complement of the nucleotide sequence.
 
@@ -209,14 +206,13 @@ class NucleotideMixin(metaclass=ABCMeta):
             GC-content: 16.67%
         -----------------------------
         0 AATGAA
-        >>> seq.positional_metadata['quality'].values
-        array([5, 4, 3, 2, 1, 0])
+        >>> seq.positional_metadata['quality'].values # doctest: +ELLIPSIS
+        array([5, 4, 3, 2, 1, 0]...
 
 
         """
         return self.complement(reverse=True)
 
-    @stable(as_of='0.4.0')
     def is_reverse_complement(self, other):
         r"""Determine if a sequence is the reverse complement of this sequence.
 
@@ -252,7 +248,7 @@ class NucleotideMixin(metaclass=ABCMeta):
         True
 
         """
-        other = self._munge_to_sequence(other, 'is_reverse_complement')
+        other = self._munge_to_sequence(other, "is_reverse_complement")
 
         # avoid computing the reverse complement if possible
         if len(self) != len(other):
@@ -263,7 +259,6 @@ class NucleotideMixin(metaclass=ABCMeta):
             # underlying sequence data
             return self.reverse_complement()._string == other._string
 
-    @stable(as_of='0.4.0')
     def gc_content(self):
         """Calculate the relative frequency of G's and C's in the sequence.
 
@@ -308,7 +303,6 @@ class NucleotideMixin(metaclass=ABCMeta):
         """
         return self.gc_frequency(relative=True)
 
-    @stable(as_of='0.4.0')
     def gc_frequency(self, relative=False):
         """Calculate frequency of G's and C's in the sequence.
 
@@ -358,9 +352,7 @@ class NucleotideMixin(metaclass=ABCMeta):
         0
 
         """
-
-        counts = np.bincount(self._bytes,
-                             minlength=self._number_of_extended_ascii_codes)
+        counts = np.bincount(self._bytes, minlength=self._num_extended_ascii_codes)
         gc = counts[self._gc_codes].sum()
         if relative:
             seq = self.degap()
@@ -374,13 +366,11 @@ _motifs = parent_motifs.copy()
 
 @_motifs("purine-run")
 def _motif_purine_run(sequence, min_length, ignore):
-    """Identifies purine runs"""
-    return sequence.find_with_regex("([AGR]{%d,})" % min_length,
-                                    ignore=ignore)
+    """Identify purine runs."""
+    return sequence.find_with_regex("([AGR]{%d,})" % min_length, ignore=ignore)
 
 
 @_motifs("pyrimidine-run")
 def _motif_pyrimidine_run(sequence, min_length, ignore):
-    """Identifies pyrimidine runs"""
-    return sequence.find_with_regex("([CTUY]{%d,})" % min_length,
-                                    ignore=ignore)
+    """Identify pyrimidine runs."""
+    return sequence.find_with_regex("([CTUY]{%d,})" % min_length, ignore=ignore)
