@@ -21,11 +21,11 @@ from skbio.metadata import IntervalMetadata
 class ExampleGrammaredSequence(GrammaredSequence):
     @classproperty
     def degenerate_map(cls):
-        return {"X": set("AB"), "Y": set("BC"), "Z": set("AC")}
+        return {"X": set("AB"), "Y": set("BC"), "Z": set("AC"), "W": set("ABCQ")}
 
     @classproperty
     def definite_chars(cls):
-        return set("ABC")
+        return set("ABCQ")
 
     @classproperty
     def default_gap_char(cls):
@@ -35,6 +35,14 @@ class ExampleGrammaredSequence(GrammaredSequence):
     def gap_chars(cls):
         return set('-.')
 
+    @classproperty
+    def noncanonical_chars(cls):
+        return "Q"
+
+    @classproperty
+    def wildcard_char(cls):
+        return "W"
+
 
 class ExampleMotifsTester(ExampleGrammaredSequence):
     @property
@@ -264,8 +272,20 @@ class TestGrammaredSequence(TestCase):
                                         invalid_type):
                 ExampleGrammaredSequence('ACGTacgt', lowercase=invalid_key)
 
+    def test_definite_char_codes(self):
+        definite_char_codes = set(ExampleGrammaredSequence._definite_char_codes)
+        self.assertEqual(definite_char_codes, set([65, 66, 67, 81]))
+
+    def test_gap_codes(self):
+        gap_codes = set(ExampleGrammaredSequence._gap_codes)
+        self.assertEqual(gap_codes, set([45, 46]))
+
+    def test_noncanonical_codes(self):
+        noncanonical_codes = set(ExampleGrammaredSequence._noncanonical_codes)
+        self.assertEqual(noncanonical_codes, set([81]))
+
     def test_degenerate_chars(self):
-        expected = set("XYZ")
+        expected = set("WXYZ")
         self.assertIs(type(ExampleGrammaredSequence.degenerate_chars), set)
         self.assertEqual(ExampleGrammaredSequence.degenerate_chars, expected)
 
@@ -281,7 +301,7 @@ class TestGrammaredSequence(TestCase):
     # TODO: duplicate of test_definite_chars, remove when nondegenerate_chars,
     # is removed
     def test_nondegenerate_chars(self):
-        expected = set("ABC")
+        expected = set("ABCQ")
         self.assertEqual(ExampleGrammaredSequence.nondegenerate_chars,
                          expected)
 
@@ -296,7 +316,7 @@ class TestGrammaredSequence(TestCase):
             ExampleGrammaredSequence('').nondegenerate_chars = set("BAR")
 
     def test_definite_chars(self):
-        expected = set("ABC")
+        expected = set("ABCQ")
         self.assertEqual(ExampleGrammaredSequence.definite_chars,
                          expected)
 
@@ -332,7 +352,7 @@ class TestGrammaredSequence(TestCase):
             ExampleGrammaredSequence('').default_gap_char = '.'
 
     def test_alphabet(self):
-        expected = set("ABC.-XYZ")
+        expected = set("ABC.-XYZQW")
         self.assertIs(type(ExampleGrammaredSequence.alphabet), set)
         self.assertEqual(ExampleGrammaredSequence.alphabet, expected)
 
@@ -345,7 +365,7 @@ class TestGrammaredSequence(TestCase):
             ExampleGrammaredSequence('').alphabet = set("ABCDEFG.-WXYZ")
 
     def test_degenerate_map(self):
-        expected = {"X": set("AB"), "Y": set("BC"), "Z": set("AC")}
+        expected = {"X": set("AB"), "Y": set("BC"), "Z": set("AC"), "W": set("ABCQ")}
         self.assertEqual(ExampleGrammaredSequence.degenerate_map, expected)
 
         ExampleGrammaredSequence.degenerate_map['W'] = set("ABC")
@@ -525,27 +545,29 @@ class TestGrammaredSequence(TestCase):
         self.assertEqual(
             ExampleGrammaredSequence(
                 "ABC-XYZ",
-                positional_metadata={'qual': np.arange(7)},
+                positional_metadata={'qual': np.arange(7, dtype=np.int64)},
                 **kw).degap(),
             ExampleGrammaredSequence(
                 "ABCXYZ",
-                positional_metadata={'qual': [0, 1, 2, 4, 5, 6]},
+                positional_metadata={'qual': np.asarray([0, 1, 2, 4, 5, 6],
+                                                        dtype=np.int64)},
                 **kw))
 
         self.assertEqual(
             ExampleGrammaredSequence(
                 ".-ABC-XYZ.",
-                positional_metadata={'qual': np.arange(10)},
+                positional_metadata={'qual': np.arange(10, dtype=np.int64)},
                 **kw).degap(),
             ExampleGrammaredSequence(
                 "ABCXYZ",
-                positional_metadata={'qual': [2, 3, 4, 6, 7, 8]},
+                positional_metadata={'qual': np.asarray([2, 3, 4, 6, 7, 8],
+                                                        dtype=np.int64)},
                 **kw))
 
         self.assertEqual(
             ExampleGrammaredSequence(
                 "---.-.-.-.-.",
-                positional_metadata={'quality': np.arange(12)},
+                positional_metadata={'quality': np.arange(12, dtype=np.int64)},
                 **kw).degap(),
             ExampleGrammaredSequence(
                 "",
@@ -683,6 +705,69 @@ class TestGrammaredSequence(TestCase):
         self.assertIn('...', obs)
         self.assertTrue(obs.endswith('300 A'))
 
+    def test_to_definites(self):
+        seq = ExampleGrammaredSequence("ABCQXYZ")
+
+        # default behavior, here I expect to see the sequence "ABCWWWW" returned
+        obs = seq.to_definites()
+        exp = ExampleGrammaredSequence("ABCWWWW")
+        self.assertEqual(obs, exp)
+
+        # noncanonical wildcard, expect to see "ABCQWWW" returned
+        obs = seq.to_definites(noncanonical=False)
+        exp = ExampleGrammaredSequence("ABCQWWW")
+
+        # gap behavior, I expect to see the sequence "ABC----" returned
+        obs = seq.to_definites(degenerate="gap")
+        exp = ExampleGrammaredSequence("ABC----")
+        self.assertEqual(obs, exp)
+
+        # noncanonical gap
+        obs = seq.to_definites(degenerate="gap", noncanonical=False)
+        exp = ExampleGrammaredSequence("ABCQ---")
+        self.assertEqual(obs, exp)
+
+        # canonical trim
+        obs = seq.to_definites(degenerate="del")
+        exp = ExampleGrammaredSequence("ABC")
+        self.assertEqual(obs, exp)
+
+        # noncanonical trim
+        obs = seq.to_definites(degenerate="del", noncanonical=False)
+        exp = ExampleGrammaredSequence("ABCQ")
+        self.assertEqual(obs, exp)
+
+        # single char, acceptable input
+        obs = seq.to_definites(degenerate="A")
+        exp = ExampleGrammaredSequence("ABCAAAA")
+        self.assertEqual(obs, exp)
+
+        # noncanonical single char, acceptable input
+        obs = seq.to_definites(degenerate="A", noncanonical=False)
+        exp = ExampleGrammaredSequence("ABCQAAA")
+        self.assertEqual(obs, exp)
+
+        # test that single char outside of alphabet will throw error
+        with self.assertRaises(ValueError):
+            seq.to_definites("P")
+
+        # test that an invalid wildcard (not a string) will throw an error
+        ExampleGrammaredSequence.wildcard_char = 1
+        with self.assertRaises(ValueError):
+            seq.to_definites()
+        ExampleGrammaredSequence.wildcard_char = 'W'
+
+        # test that nonsense input for 'to' will throw error
+        with self.assertRaises(ValueError):
+            seq.to_definites(degenerate='nonsense')
+
+    def test_noncanonical_chars(self):
+        self.assertTrue(isinstance(GrammaredSequence.noncanonical_chars, set))
+        self.assertEqual(len(GrammaredSequence.noncanonical_chars), 0)
+    
+    def test_wildcard_char(self):
+        exp = None
+        self.assertEqual(GrammaredSequence.wildcard_char, exp)
 
 if __name__ == "__main__":
     main()
