@@ -1,34 +1,61 @@
-r"""
-Ordination methods (:mod:`skbio.stats.ordination`)
+r"""Ordination methods (:mod:`skbio.stats.ordination`)
 ==================================================
 
 .. currentmodule:: skbio.stats.ordination
 
-This module contains several ordination methods, including Principal
-Coordinate Analysis, Correspondence Analysis, Redundancy Analysis and
-Canonical Correspondence Analysis.
+This module provides functions for ordination -- a category of methods that aim at
+arranging data so that similar data points are proximate to each other. Ordination can
+preserve and represent the structure of high-dimensional data within a low-dimensional
+space, thereby facilitating visual exploration and statistical analysis.
 
-Ordination Functions
---------------------
+Mathematically, ordination shares similarities with, and is in multiple respects
+equivalent to, embedding and dimensionality reduction. While all three aim to represent
+high-dimensional data in a lower-dimensional space, the term "ordination" is mainly
+used in the field of ecology to reveal patterns such as groups or gradients underlying
+community data. However, the ordination methods implemented in scikit-bio are
+versatile, serving not only ecological studies but also broader applications in
+scientific computing.
+
+
+Multidimensional scaling
+------------------------
+
+.. autosummary::
+   :toctree:
+
+   pcoa
+   pcoa_biplot
+
+
+Correspondence analysis
+-----------------------
 
 .. autosummary::
    :toctree:
 
    ca
-   pcoa
-   pcoa_biplot
+
+
+Canonical analysis
+------------------
+
+.. autosummary::
+   :toctree:
+
    cca
    rda
 
-Classes
--------
+
+Ordination results
+------------------
 
 .. autosummary::
    :toctree:
 
    OrdinationResults
 
-Utility Functions
+
+Utility functions
 -----------------
 
 .. autosummary::
@@ -41,9 +68,9 @@ Utility Functions
    e_matrix
    f_matrix
 
+
 Examples
 --------
-
 This is an artificial dataset (table 11.3 in [1]_) that represents fish
 abundance in different sites (`Y`, the response variables) and
 environmental variables (`X`, the explanatory variables).
@@ -115,11 +142,11 @@ dtype: float64
 
 References
 ----------
-
 .. [1] Legendre P. and Legendre L. 1998. Numerical Ecology. Elsevier,
    Amsterdam.
 
-"""
+
+"""  # noqa: D205, D415
 
 # ----------------------------------------------------------------------------
 # Copyright (c) 2013--, scikit-bio development team.
@@ -134,9 +161,28 @@ from ._correspondence_analysis import ca
 from ._canonical_correspondence_analysis import cca
 from ._principal_coordinate_analysis import pcoa, pcoa_biplot
 from ._ordination_results import OrdinationResults
-from ._utils import (mean_and_std, scale, svd_rank, corr, e_matrix, f_matrix,
-                     center_distance_matrix)
+from ._utils import (
+    mean_and_std,
+    scale,
+    svd_rank,
+    corr,
+    e_matrix,
+    f_matrix,
+    center_distance_matrix,
+)
 
-__all__ = ['ca', 'rda', 'cca', 'pcoa', 'pcoa_biplot', 'OrdinationResults',
-           'mean_and_std', 'scale', 'svd_rank', 'corr',
-           'e_matrix', 'f_matrix', 'center_distance_matrix']
+__all__ = [
+    "ca",
+    "rda",
+    "cca",
+    "pcoa",
+    "pcoa_biplot",
+    "OrdinationResults",
+    "mean_and_std",
+    "scale",
+    "svd_rank",
+    "corr",
+    "e_matrix",
+    "f_matrix",
+    "center_distance_matrix",
+]
