@@ -13,6 +13,7 @@ import numpy as np
 from skbio._base import SkbioObject
 from skbio.stats._misc import _pprint_strs
 from skbio.util._plotting import PlottableMixin
+from skbio.io.registry import Read, Write
 
 
 class OrdinationResults(SkbioObject, PlottableMixin):
@@ -59,6 +60,9 @@ class OrdinationResults(SkbioObject, PlottableMixin):
 
     default_write_format = "ordination"
 
+    read = Read()
+    write = Write()
+
     def __init__(
         self,
         short_method_name,
