@@ -7,5 +7,10 @@
 # ----------------------------------------------------------------------------
 
 from biom import Table, example_table
+from skbio.io.registry import Read, Write
 
 Table.default_write_format = "biom"
+
+# Define read and write methods for the Table class.
+Table.read = Read()
+Table.write = Write()
